@@ -17,9 +17,8 @@ def get_search_result_type(result_type_local, result_types_local):
 
 
 def parse_top_result(data, search_result_types):
-    search_result = {}
     result_type = get_search_result_type(nav(data, SUBTITLE), search_result_types)
-    search_result['resultType'] = result_type
+    search_result = {'category': nav(data, CARD_SHELF_TITLE), 'resultType': result_type}
     if result_type == 'artist':
         subscribers = nav(data, SUBTITLE2, True)
         if subscribers:
@@ -28,6 +27,12 @@ def parse_top_result(data, search_result_types):
         artist_info = parse_song_runs(nav(data, ['title', 'runs']))
         search_result.update(artist_info)
 
+    if result_type in ['song', 'video']:
+        on_tap = data.get('onTap')
+        if on_tap:
+            search_result['videoId'] = nav(on_tap, WATCH_VIDEO_ID)
+            search_result['videoType'] = nav(on_tap, NAVIGATION_VIDEO_TYPE)
+
     if result_type in ['song', 'video', 'album']:
         search_result['title'] = nav(data, TITLE_TEXT)
         runs = nav(data, ['subtitle', 'runs'])[2:]
@@ -41,8 +46,8 @@ def parse_top_result(data, search_result_types):
 def parse_search_result(data, search_result_types, result_type, category):
     default_offset = (not result_type) * 2
     search_result = {'category': category}
-    if video_type := nav(data, PLAY_BUTTON + ['playNavigationEndpoint'] + NAVIGATION_VIDEO_TYPE,
-                         True):
+    video_type = nav(data, PLAY_BUTTON + ['playNavigationEndpoint'] + NAVIGATION_VIDEO_TYPE, True)
+    if not result_type and video_type:
         result_type = 'song' if video_type == 'MUSIC_VIDEO_TYPE_ATV' else 'video'
 
     result_type = get_search_result_type(get_item_text(data, 1),
@@ -121,8 +126,6 @@ def parse_search_result(data, search_result_types, result_type, category):
 
     if result_type in ['artist', 'album', 'playlist']:
         search_result['browseId'] = nav(data, NAVIGATION_BROWSE_ID, True)
-        if not search_result['browseId']:
-            return {}
 
     if result_type in ['song', 'album']:
         search_result['isExplicit'] = nav(data, BADGE_LABEL, True) is not None
@@ -193,3 +196,25 @@ def get_search_params(filter, scope, ignore_spelling):
 def _get_param2(filter):
     filter_params = {'songs': 'I', 'videos': 'Q', 'albums': 'Y', 'artists': 'g', 'playlists': 'o'}
     return filter_params[filter]
+
+
+def parse_search_suggestions(results, detailed_runs):
+    if not results.get('contents', [{}])[0].get('searchSuggestionsSectionRenderer', {}).get(
+            'contents', []):
+        return []
+
+    raw_suggestions = results['contents'][0]['searchSuggestionsSectionRenderer']['contents']
+    suggestions = []
+
+    for raw_suggestion in raw_suggestions:
+        suggestion_content = raw_suggestion['searchSuggestionRenderer']
+
+        text = suggestion_content['navigationEndpoint']['searchEndpoint']['query']
+        runs = suggestion_content['suggestion']['runs']
+
+        if detailed_runs:
+            suggestions.append({'text': text, 'runs': runs})
+        else:
+            suggestions.append(text)
+
+    return suggestions
